@@ -1,6 +1,6 @@
 package Vroom::Vroom::Link;
 BEGIN {
-  $Vroom::Vroom::Link::VERSION = '0.05';
+  $Vroom::Vroom::Link::VERSION = '0.06';
 }
 
 use parent qw/Vroom/;
@@ -26,7 +26,7 @@ sub makeHTML {
         $text = Template::Toolkit::Simple->new()->render(
             $self->slideTemplate,
             {
-                title => "$slide",
+                title => $self->config->{title} . " $slide",
                 prev => $prev,
                 next => $next,
                 content => \@textwithLinks,
